
# Twenty Fifteen

A clean, responsive, blog-focused theme based on the default WordPress theme
of the same name.


## Includes

This theme supports the following include files:

* `menu`
* `sidebar`
* `footer`


# License

GNU General Public License v2 or later.
